@@ -158,9 +158,14 @@ class DBAccess
         catch(PDOException $e){ 
             if ($LOG_ERROR)
                 error_log(' [DBMS/query]: '.$e->getMessage());
-            throw new Exception('ERR_DBQUERY');
         }
-        return new DBResult($this->_sth->fetchAll(PDO::FETCH_ASSOC));
+        try {
+            $result = $this->_sth->fetchAll(PDO::FETCH_ASSOC);
+        }
+        catch (PDOException $e) {
+            $result = '';
+        }
+        return new DBResult($result);
     }
 
     
