@@ -85,19 +85,6 @@ class EMail
     }
 
 
-    /**
-     * Returs the time of the email as a strftime string
-     *
-     * @access public
-     * @param format (default: "%d.%m.%Y "%H:%M)
-     * @return string $date
-     */
-    function getDateString($format='%d.%m.%Y %H:%M')
-    {
-        return strftime($format,strtotime($this->date));
-    }
-
-
     /**
      * Returns string with header field
      *
