@@ -36,9 +36,15 @@ require 'model/Benno.php';
 
 $Benno = new Benno();
 
-$License = $Backend->fetchLicense();
+try {
+    $License = $Backend->fetchLicense();
+    $App->assign('License',$License);
+}
+catch (Exception $e) {
+    $App->log('Cannot fetch license data from backend: '.$e->getMessage());
+    $App->setMsg($e->getMessage());
+}
 
-$App->assign('License',$License);
 $App->assign('Benno',$Benno);
 $App->assign('FilterList',$FilterList);
 
