@@ -74,4 +74,8 @@ $App->assign('sortOrder',$sortOrder);
 if (isset($displayedMailId))
     $App->assign('displayedMailId',$displayedMailId);
 
+if (isset($queryId)) // display current stored query
+    $App->assign('queryId',$queryId);
+
+
 ?>
